﻿using System;
using System.Drawing;

namespace PV178.Lecture2
{
    /// <summary>
    ///   Třída přestavující automobil. Dva automobily jsou považovány za stejné právě když mají stejný VIN.
    /// </summary>
    internal class Car
    {
        /// <summary>
        ///   Jednoznačný identifikátor vozidla vyražený do karoserie.
        /// </summary>
        public VehicleIdentificationNumber VehicleIdentificationNumber { get; private set; }

        /// <summary>
        ///   Barva vozidla.
        /// </summary>
        /// <remarks>
        ///   Třída Color je v assembly System.Drawings.dll.
        /// </remarks>
        public Color Color { get; set; }

        /// <summary>
        ///   Palivo vozidla.
        /// </summary>
        public Fuel Fuel { get; set; }


        /// <summary>
        ///   Vytvoří auto se zadaným VIN.
        /// </summary>
        /// <param name="vin"> VIN automobilu. </param>
        /// <exception cref="ArgumentException">Pokud VIN není platný.</exception>
        public Car(VehicleIdentificationNumber vin)
        {
            if (vin == VehicleIdentificationNumber.Empty)
                throw new ArgumentException("Vehicle Identification Number has invalid value.", "vin");

            VehicleIdentificationNumber = vin;
        }

        /// <summary>
        ///   Vytvoří auto se zadaným VIN a barvou jezdící na dané palivo.
        /// </summary>
        /// <param name="vin"> VIN automobilu. </param>
        /// <param name="color"> Barva vozidla. </param>
        /// <param name="fuel"> Palivo na které automobil jezdí. </param>
        public Car(VehicleIdentificationNumber vin, Color color, Fuel fuel)
            : this(vin)
        {
            Color = color;
            Fuel = fuel;
        }


        public override bool Equals(object obj)
        {
            if (obj == null || GetType() != obj.GetType())
            {
                return false;
            }

            Car otherCar = (Car) obj;
            return VehicleIdentificationNumber.Equals(otherCar.VehicleIdentificationNumber);
        }

        public override int GetHashCode()
        {
            return VehicleIdentificationNumber.GetHashCode();
        }
    }
}